==> humhub-1.4.1.tar.gz: humhub-1.4.1/protected/humhub/modules/marketplace/messages/fr/base.php <==
<?php
return array (
  '
Module successfully disabled!
' => 'Module déactivé avec succès',
  '
Module successfully enabled!
' => 'Module activé avec succès',
  '--- Disable module: {moduleId} ---

' => '--Désactivé module:{moduleId} --- ',
  '--- Enable module: {moduleId} ---

' => '--Activé module:{moduleld}--',
  'Add purchased module by licence key' => 'Ajouter un module acheté par sa clé de licence',
  'All modules are up to date!' => 'Tous les modules sont à jour.',
  'All {moduleId} module content will be deleted. Continue?' => '',
  'Available updates' => 'Mise à jour',
  'Browse online' => 'Voir en ligne',
  'Buy (%price%)' => 'Acheter (%price%)',
  'Could not extract module!' => 'Impossible d\'extraire le module.',
  'Download of module failed!' => 'Erreur de téléchargement du module.',
  'Install' => 'Installer',
  'Installed' => 'Installé',
  'Installed version:' => 'Version installée :',
  'Installing module...' => 'Installation du module...',
  'Latest compatible Version:' => 'Dernière version compatible :',
  'Latest compatible version:' => 'Dernière version compatible :',
  'Latest version:' => 'Dernière version : ',
  'Licence Key:' => 'Clé de licence :',
  'Marketplace' => '',
  'Module directory %modulePath% is not writeable!' => 'Le dossier du module %modulePath% est en lecture seule.',
  'Module download failed! (%error%)' => 'Erreur de téléchargement du module (%error%)',
  'Module not found or activated!
' => 'Module introuvable ou activé',
  'Module not found!
' => 'Module introuvable ! ',
  'More info' => 'Plus d\'infos',
  'No compatible module version found!' => 'Version du module non compatible.',
  'No modules found!' => 'Aucun module trouvé.',
  'No purchased modules found!' => 'Aucun module acheté trouvé.',
  'Ok' => 'Ok',
  'Purchases' => 'Achats',
  'Register' => 'S\'enregistrer',
  'Search' => 'Recherche',
  'The HumHub developers provide no support for third-party modules and neighter give any guarantee about the suitability, functionality or security of this module.' => 'Les développeurs de HumHub ne fournisent aucun support pour les modules tiers et ne garantissent pas leur fonctionnement, suivi et sécurité.',
  'Third-party' => 'Tierces-parties',
  'Third-party disclaimer' => 'Avertissement externe',
  'Update' => 'Mettre à jour',
  'Updating module...' => 'Mise à jour du module...',
  'search for available modules online' => 'rechercher des modules disponibles en ligne',
);

==> humhub-1.4.2.tar.gz: humhub-1.4.2/protected/humhub/modules/marketplace/messages/fr/base.php <==
<?php
return array (
  '
Module successfully disabled!
' => 'Module déactivé avec succès',
  '
Module successfully enabled!
' => 'Module activé avec succès',
  '--- Disable module: {moduleId} ---

' => '--Désactivé module:{moduleId} ---',
  '--- Enable module: {moduleId} ---

' => '--Activé module:{moduleld}--',
  'Add purchased module by licence key' => 'Ajouter un module acheté par sa clé de licence',
  'All modules are up to date!' => 'Tous les modules sont à jour.',
  'All {moduleId} module content will be deleted. Continue?' => 'Tout le contenu du module {moduleId} sera supprimé. Continuer ?',
  'Available updates' => 'Mise à jour',
  'Browse online' => 'Voir en ligne',
  'Buy (%price%)' => 'Acheter (%price%)',
  'Could not extract module!' => 'Impossible d\'extraire le module.',
  'Download of module failed!' => 'Erreur de téléchargement du module.',
  'Install' => 'Installer',
  'Installed' => 'Installé',
  'Installed version:' => 'Version installée :',
  'Installing module...' => 'Installation du module...',
  'Latest compatible Version:' => 'Dernière version compatible :',
  'Latest compatible version:' => 'Dernière version compatible :',
  'Latest version:' => 'Dernière version :',
  'Licence Key:' => 'Clé de licence :',
  'Marketplace' => 'Marketplace',
  'Module directory %modulePath% is not writeable!' => 'Le dossier du module %modulePath% est en lecture seule.',
  'Module download failed! (%error%)' => 'Erreur de téléchargement du module (%error%)',
  'Module not found or activated!
' => 'Module introuvable ou activé',
  'Module not found!
' => 'Module introuvable !',
  'More info' => 'Plus d\'infos',
  'No compatible module version found!' => 'Version du module non compatible.',
  'No modules found!' => 'Aucun module trouvé.',
  'No purchased modules found!' => 'Aucun module acheté trouvé.',
  'Ok' => 'Ok',
  'Purchases' => 'Achats',
  'Register' => 'S\'enregistrer',
  'Search' => 'Recherche',
  'The HumHub developers provide no support for third-party modules and neighter give any guarantee about the suitability, functionality or security of this module.' => 'Les développeurs de HumHub ne fournisent aucun support pour les modules tiers et ne garantissent pas leur fonctionnement, suivi et sécurité.',
  'Third-party' => 'Tierces-parties',
  'Third-party disclaimer' => 'Avertissement externe',
  'Update' => 'Mettre à jour',
  'Updating module...' => 'Mise à jour du module...',
  'search for available modules online' => 'rechercher des modules disponibles en ligne',
);
